SWDEV-236178 - Remove __hip_pinned_shadow reference from dtests and add hipModuleUnload for all corresponding hipModuleLoad calls.

Change-Id: I405789b430ffbb8fccda1cebdb5d18e83a85c926


[ROCm/hip commit: 0dd6123998]
This commit is contained in:
kjayapra-amd
2020-06-11 17:23:41 -04:00
committed by Karthik Jayaprakash
orang tua 44930cfb52
melakukan f2c6f3bf63
5 mengubah file dengan 6 tambahan dan 7 penghapusan
+1 -4
Melihat File
@@ -27,10 +27,7 @@ THE SOFTWARE.
#include "hip/hip_runtime.h"
#if __HIP__
__hip_pinned_shadow__
#endif
extern texture<float, 2, hipReadModeElementType> tex;
texture<float, 2, hipReadModeElementType> tex;
extern "C" __global__ void tex2dKernel(float* outputData, int width, int height) {
int x = hipBlockIdx_x * hipBlockDim_x + hipThreadIdx_x;